@@ -26,9 +26,16 @@ class ReqClient:
         self.base_client.ws.close()
 
     def __repr__(self):
+        return type(
+            self
+        ).__name__ + "(host='{host}', port={port}, password='{password}')".format(
+            **self.base_client.__dict__,
+        )
+
+    def __str__(self):
         return type(self).__name__
 
-    def send(self, param, data=None):
+    def send(self, param, data=None, raw=False):
         response = self.base_client.req(param, data)
         if not response["requestStatus"]["result"]:
             error = (
@@ -38,6 +45,8 @@ class ReqClient:
                 error += (f"With message: {response['requestStatus']['comment']}",)
             raise OBSSDKError("\n".join(error))
         if "responseData" in response:
+            if raw:
+                return response["responseData"]
             return as_dataclass(response["requestType"], response["responseData"])
 
     def get_version(self):
@@ -1729,7 +1738,10 @@ class ReqClient:
 
 
         """
-        self.send("SendStreamCaption")
+        payload = {
+            "captionText": caption,
+        }
+        self.send("SendStreamCaption", payload)
 
     def get_record_status(self):
         """
